Unreleased
----------

* [Feature] Task list on the web interface.
* [Feature] Queue list on the web interface.

0.2.0 (2017/02/07)
------------------

* [Feature] Store history of messages into database.
* [Feature] Show history of messages on the web interface.

0.1.0 (2017/02/05)
------------------

* [Feature] Provide the web interface.

0.0.2 (2017/02/03)
------------------

* [Fix] Celery name was static.

0.0.1 (2017/02/03)
------------------

* [Feature] Initial release.
